<?php

namespace Garradin;

require_once __DIR__ . '/_inc.php';
require_once PLUGIN_ROOT . '/lib/MPDF/vendor/autoload.php';

$session->requireAccess('compta', Membres::DROIT_ACCES);

$membres = new Membres;

qv(['id' => 'required|numeric']);
$id = (int) qg('id');

$f = $facture->get($id);

if (!$f)
{
	throw new UserException("Ce document n'existe pas.");
}

$cats = new Compta\Categories;
$moyen_paiement = $cats->getMoyenPaiement($f->moyen_paiement);

try
{
	if ($f->receveur_membre)
	{
		$c = $membres->get($f->receveur_id);
		foreach(['ville','code_postal','adresse'] as $v)
		{
			if($c->$v == '')
			{
				$c->$v = '[A RENSEIGNER DANS LA FICHE MEMBRE]';
			}
		}
	}
	else
	{
		$c = $client->get($f->receveur_id);
	}
}
catch(UserException $e)
{
	$form->addError("Pas de document correspondant à cet id trouvée."); 
}

// Création du PDF

$pdf = new \Mpdf\Mpdf([
	'default_font_size' => 10,
	'default_font' => 'dejavusans',
	// 'tempDir' => PLUGINS_ROOT . '/mpdf-tmp/'
]);
$pdf->SetAuthor($config->get('nom_asso'));

ob_start();

$doc = ($f->type_facture?'Facture':'Devis').' n°'.$f->numero;
$emission = date('d/m/Y' ,$f->date_emission);
$pdf->SetTitle($doc.' - '.$emission);

$asso =
	// 'Émis par :<br><br>'.
	'<b>'.$config->get('nom_asso')."</b><br>".
	str_replace("\n", '<br>', $config->get('adresse_asso'))."<br>".
	(($t = $cfg->get('siret_asso'))?"SIRET : $t<br>":'').
	(($t = $config->get('email_asso'))?"Email : $t<br>":'').
	(($t = $config->get('site_asso'))?"Site web : $t<br>":'');

$receveur =
	'Adressé à :<br><br>'.
	'<b>'.$c->nom.'</b><br>'.
	$c->adresse."<br>".
	$c->code_postal.' '.$c->ville."<br>".
	(($t = $c->email)?"Email : $t<br>":'').
	(($t = $c->telephone)?"Tel : $t<br>":'');

$total = number_format($f->total, 2, ',', ' ');
$echeance = date('d/m/Y' ,$f->date_echeance);
$echeance = ($f->type_facture?'Échéance de paiement':'Échéance du devis')." : ".$echeance;
$reglee = !$f->reglee?'Cette facture est en attente de règlement.':'Cette facture a été reglée.';
$footer = str_replace("\n", '<br>', $cfg->get('footer'));


echo <<<EOF
<!-- STYLE -->

<style>
    .titre {
	text-align: center;
	font-size: 8pt;
	position: absolute;
	top: 6mm;
	width: 180mm;
    }
    .h2 {
	margin: 25 20 0 20;
    }
    .h2 span {
	font-weight: bold;
	font-size: 15pt;
    }
    hr {
	margin: 5 0 20 0;
    }
    .adressage {
	font-size: 11pt;
    }
    .adressage td {
	width: 95mm;
	vertical-align: top;
    }

    .contenu td, .contenu th {
	vertical-align: top;
	padding: 8 10;
	margin : 0;
	border-collapse: collapse;
    }

    .contenu tr th, .contenu tr td {
	text-align: right;
	width: 16%;
    }
    .contenu tr td:nth-child(1), .contenu tr th:nth-child(1) {
	text-align: left;
	width: 84%;
    }

    .contenu thead tr, .contenu tfoot tr {
	background-color: #CCE;
	border: 10px solid black;
    }
    .contenu tbody tr:nth-child(even) {
	background-color: #DDF;
    }

    footer {
	position: absolute;
	bottom: 0;
	margin: 14mm 0;
    }

</style>

<!-- CONTENU -->

<p class="titre">
$doc - Émis le $emission
</p>

<table class="adressage">
    <tr>
	<td>$asso</td>
	<td>$receveur</td>
    </tr>
</table>

<br>

<div class="h2">
    <span>Contenu</span> - $doc
</div>
<hr>

<table class="contenu">
    <thead>
	<tr>
	    <th>
		Désignations
	    </th>
	    <th>
		Prix
	    </th>
	</tr>
    </thead>
    <tbody>
EOF;

$i = 1;
foreach($f->contenu as $k=>$v)
{   
	echo '<tr><td>';
	echo str_replace("\n", '<br>', $v['designation']);
	echo '</td><td>';
	echo number_format($v['prix'], 2, ',', ' ').'€';
	echo '</td></tr>';
	$i++;
}

echo <<<EOF
    </tbody>
    <tfoot>
	<tr>
	<td><h3>Total</h3>Net à payer</td>
	<td><b>$total €</b> (HT)</td>
	</tr>
    </tfoot>
</table>


<footer>
    <div class="h2"><span>Détails</span></div>
    <hr>

    $echeance <br>
    $reglee
    Moyen de paiement : $moyen_paiement

    <p>
	$footer
    </p>

</footer>
EOF;


$html = ob_get_clean();
$pdf->WriteHTML($html);

if(qg('d') !== null)
{
	$t = \Mpdf\Output\Destination::DOWNLOAD;
}
else
{
	$t = \Mpdf\Output\Destination::INLINE;
}
$pdf->Output(    
	($f->type_facture?'Facture':'Devis').' '.$f->numero
	. ' du '.date('d-m-Y' ,$f->date_emission)
	.'.pdf', $t);
